
  <!-- Root account usage -->
  <script id="services.iam.credential_report.root_account.details.template" type="text/x-handlebars-template">
    <div id="services.iam.credential_report.<root_account>.details">
        <div class="list-group" id="services.iam.credential_report.<root_account>.view">
          <div class="list-group-item active">
            <h4 class="list-group-item-heading">AWS root account</h4>
          </div>
          <div class="list-group-item">
            <div class="list-group-item-text item-margin">Creation date: {{items.user_creation_time}}</div>
            <div class="list-group-item-text item-margin">Password last used: <span id="iam.credential_report.<root_account>.password_last_used">{{items.password_last_used}}</span></div>
            <div class="list-group-item-text item-margin">MFA enabled: <span id="iam.credential_report.<root_account>.mfa_active">{{items.mfa_active}}</span></div>
            <div class="list-group-item-text item-margin">Access key 1 active: <span id="iam.credential_report.<root_account>.access_key_1_active">{{items.access_key_1_active}}</span></div>
            <div class="list-group-item-text item-margin">Access key 2 active: <span id="iam.credential_report.<root_account>.access_key_2_active">{{items.access_key_2_active}}</span></div>
            <div class="list-group-item-text item-margin">Signing cert 1 active: {{items.cert_1_active}}</div>
            <div class="list-group-item-text item-margin">Signing cert 2 active: {{items.cert_2_active}}</div>
          </div>
        </div>
    </div>
  </script>
 

