# -*- coding: utf-8 -*-

__author__  = 'l01cd3v'
__version__ = '3.2.0'

AWSCONFIG  = 42
EXCEPTIONS = 4242
HTMLREPORT = 424242
AWSRULESET = 42424242

DEFAULT_REPORT_DIR = 'scout2-report'
AWSCONFIG_FILE  = 'inc-awsconfig/aws_config.js'
AWSRULESET_FILE = 'inc-awsconfig/aws_ruleset.js'
EXCEPTIONS_FILE = 'inc-awsconfig/exceptions.js'
HTMLREPORT_FILE = 'report.html'
GENERATOR_FILE  = 'ruleset-generator.html'

REPORT_TITLE  = 'AWS Scout2 Report'
