
<!-- Trail partial -->
<script id="services.cloudtrail.regions.partial" type="text/x-handlebars-template">
    <div class="list-group-item active">
      <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
    <h4>Information</h4>
      <ul>
        <li class="list-group-item-text">Configured:
          <span>
          <span id="cloudtrail.regions.{{name}}.NotConfigured">
            {{#ifPositive trails_count}}Yes{{else}}No{{/ifPositive}}</li>
          </span>
      </ul>
    </div>
    <div class="list-group-item">
      <div class="accordion">
        <h4 class="list-group-item-heading accordion-heading">Trails
          {{#ifPositive trails_count}}
            <a class="accordion-toggle" data-toggle="collapse" href="#cloudtrail\.regions\.{{name}}\.trails"><span class="badge pull-right btn-info">{{trails_count}}</span></a>
          {{else}}
            <span class="badge pull-right">{{trails_count}}</span>
          {{/ifPositive}}
        </h4>
        <div id="cloudtrail.regions.{{name}}.trails" class="accordion-body collapse">
          <div class="accordion-inner">
            <ul class="no-bullet">
              {{#each trails}}
                <li><a href="javascript:showObject('services.cloudtrail.regions.{{../name}}.trails.{{@key}}')">{{name}}</a></li>
              {{/each}}
            </ul>
          </div>
        </div>
      </div>
    </div>
</script>
<script>
  Handlebars.registerPartial("services.cloudtrail.regions", $("#services\\.cloudtrail\\.regions\\.partial").html());
</script>

