
  <!-- Generic partial for region-then-resource -->
  <script id="details_for_region.partial" type="text/x-handlebars-template">
    <div id="services.{{service_name}}.regions.id.{{resource_type}}.details">
      {{#each items}}
        {{#each (lookup . ../resource_type)}}
          <div class="list-group" id="services.{{../../service_name}}.regions.{{@../key}}.{{../../resource_type}}.{{@key}}.view">
            {{> (lookup ../.. 'partial_name') service_name = ../../service_name region = @../key resource_type = ../../resource_type resource_key = @key resource = this}}
          </div>
        {{/each}}
      {{/each}}
    </div>
  </script>
  <script>
    Handlebars.registerPartial("details_for_region", $("#details_for_region\\.partial").html());
  </script>

